#
# spec file for package libXcm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libXcm
Version:        0.5.4
Release:        1.18
Summary:        X Color Management Library
License:        MIT
Group:          Productivity/Graphics/Other
Url:            http://www.oyranos.org
#Git-Clone:	git://github.com/oyranos-cms/libxcm
Source:         %{name}-%version.tar.gz
Source1:        libxcm_0.5.4.orig.tar.bz2
Source2:        libxcm_0.5.4-1.debian.tar.gz
Source3:        libxcm.dsc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} != 0 && 0%{?suse_version} < 1130
BuildRequires:  Mesa-devel
BuildRequires:  xorg-x11-devel
%else
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xmu)
%endif

%package -n %{name}0
Summary:        X Color Management Library
Group:          System/Libraries

%package -n %{name}EDID0
Summary:        EDID Color Management Parsing
Group:          System/Libraries

%package -n %{name}DDC0
Summary:        EDID over DDC Detection
Group:          System/Libraries

%package -n %{name}X11-0
Summary:        X Color Management Implementation
Group:          System/Libraries

%package devel
Summary:        Headers, Configuration and static Libs + Documentation
Group:          Development/Libraries/C and C++
Requires:       %{name}0 = %{version}
Requires:       %{name}DDC0 = %{version}
Requires:       %{name}EDID0 = %{version}
Requires:       %{name}X11-0 = %{version}

%description
The libXcm library is a color management helper for Xorg. It contains a
reference implementation of the X Color Management specification.
It allows to attach color regions to X windows to communicate with colour
servers. A EDID parser and a observer tool are included.

%description -n %{name}0
The libXcm library is a reference implementation of the X Color Management specification.
It allows to attach color regions to X windows to communicate with color
servers. A EDID parser and a color management event observer are included.

%description -n %{name}EDID0
EDID parser implementing the key/value pairs needed for the ICC meta Tag for Monitor Profiles spec.
http://www.freedesktop.org/wiki/Specifications/icc_meta_tag_for_monitor_profiles

%description -n %{name}DDC0
Provide EDID detection through display data channel (DDC) communication.

%description -n %{name}X11-0
The libXcmX11 library is a reference implementation of the X Color Management specification.
It allows to attach color regions to X windows to communicate with color
+servers.

%description devel
The libXcm library is a reference implementation of the X Color Management specification.
It allows to attach color regions to X windows to communicate with color
servers. A EDID parser and a color management event observer are included.
The package contains headers and other development files.

%prep
%setup -q

%build
%ifarch %{arm}
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%endif
%configure --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

#Remove installed doc
rm -fr %{buildroot}/%{_datadir}/doc/%{name}

#Fix timestamp to prevent multilibs conflict
touch -r docs/ChangeLog.md doc/man/*

# Remove libtool files
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}0 -p /sbin/ldconfig

%post -n %{name}EDID0 -p /sbin/ldconfig

%post -n %{name}DDC0 -p /sbin/ldconfig

%post -n %{name}X11-0 -p /sbin/ldconfig

%postun -n %{name}0 -p /sbin/ldconfig

%postun -n %{name}EDID0 -p /sbin/ldconfig

%postun -n %{name}DDC0 -p /sbin/ldconfig

%postun -n %{name}X11-0 -p /sbin/ldconfig

%files -n %{name}0
%defattr(-, root, root)
%{_libdir}/%{name}.so.*

%files -n %{name}EDID0
%defattr(-, root, root)
%{_libdir}/%{name}EDID.so.*

%files -n %{name}DDC0
%defattr(-, root, root)
%{_libdir}/%{name}DDC.so.*

%files -n %{name}X11-0
%defattr(-, root, root)
%{_libdir}/%{name}X11.so.*

%files devel
%defattr(-, root, root)
%doc docs/AUTHORS.md docs/COPYING.md docs/ChangeLog.md README.md
%doc docs/X_Color_Management.md
%{_libdir}/%{name}*.so
%{_libdir}/cmake/
%{_includedir}/X11/Xcm/
%{_libdir}/pkgconfig/xcm*.pc
%{_mandir}/man3/*.3*

%changelog
* Thu Dec 22 2016 ku.b@gmx.de
- fix spec file
* Tue Nov 29 2016 ku.b@gmx.de - 0.5.4
- Update to 0.5.4
- show _NET_DESKTOP_GEOMETRY event
- fix warnings from code audit
- fix leaks from code audit
- fix use of correct deallocator
* Mon Dec  7 2015 jengelh@inai.de
- Update Git-Clone location and RPM groups. Use source URL.
  Trim filelist.
* Thu Oct 23 2014 tchvatal@suse.com
- Add debian stuff to sources so it actually can be SR# to Factory
* Mon Oct 13 2014 tchvatal@suse.com
- Simplify the deps so it builds everywhere using pc files.
  Readability++
* Mon Oct 13 2014 tchvatal@suse.com
- Fix sle11 build.
* Wed Oct  1 2014 crrodriguez@opensuse.org
- Cleanup buildRequires so only what is really needed
  gets pulled for build
* Wed Apr 24 2013 ku.b@gmx.de
- split into EDID, DDC and X11 libraries
- Patch for transposed EDID red y bits (Florian Höch)
- initialy observe windows
- remove all libtool files from RPM
- call split libraries in libXcm to auto resolve dependencies
- Fix window name print
- omit XmuClientWindow() call
* Thu Dec 20 2012 ku.b@gmx.de
- add |ICM| alias XCM_COLOR_SERVER_MANAGEMENT attribute
- add FindXcm.cmake
* Tue Nov 27 2012 jengelh@inai.de
- Supply Git-Clone URL, update download/source URL, and remove
  "evil" Prefix: tag
* Sat Nov 24 2012 ku.b@gmx.de
- add libxmu-dev build requirement
* Sat Nov 24 2012 ku.b@gmx.de
- add pkg-config build requirement
* Sat Nov 24 2012 ku.b@gmx.de
- fix X11 build requirements
* Sat Nov 24 2012 ku.b@gmx.de
- use development version
- only minor build improvements
* Mon May 28 2012 ku.b@gmx.de
- Update to 0.5.1
* Tue Apr  3 2012 ku.b@gmx.de
- use of autotools
- switch to X Color Management spec from net-color spec.
- some more features where added
- all found bugs or fixed
- details http://www.oyranos.org/2012/03/libxcm-0-5-0-released/
- full ChangeLog http://www.oyranos.org/scm?p=xcolor.git;a=blobdiff;f=ChangeLog;h=b44ea8252a2039074ddcdbabbe8eea1fc44a12ca;hp=1198b093f724da40a6fa1aae264abd969a13609c;hb=2e1562482e2d8549db6111d401d5be7b55c5680c;hpb=68fe9706a48121eb68a1cce057a93e4235d28d7f
* Mon Apr  2 2012 ku.b@gmx.de
- use final source package
* Mon Apr  2 2012 ku.b@gmx.de
- fix download link
* Fri Mar  9 2012 ku.b@gmx.de
- Update to 0.5.0
* Fri Oct 14 2011 mhrusecky@suse.cz
- add -fPIC on %%arm (fixed build)
* Thu Sep 15 2011 ku.b@gmx.de
- add spec license
* Fri Sep  9 2011 ku.b@gmx.de
- omit empty clean section in spec file
* Thu Sep  8 2011 ku.b@gmx.de
- omit RPM_BUILD_ROOT removal
  * Wed Dec 29 2010 Kai-Uwe Behrmann
- include basic i2c DDC/CI - 0.4.0
  * Fri Oct 01 2010 Kai-Uwe Behrmann
- include EDID parser - 0.3.0
- include Xcm Events API
- headers move to a own sub directory
  * Mon Jul 19 2010 Kai-Uwe Behrmann
- sync with Nicolas Chauvet <kwizart@gmail.com> - 0.2.6-2
  * Thu Jun 03 2010 Kai-Uwe Behrmann
- initial
